Utf16CharsWithTrieEx

Trait Utf16CharsWithTrieEx 

pub trait Utf16CharsWithTrieEx<'slice, 'trie, T, V>
where V: TrieValue, T: AbstractCodePointTrie<'trie, V>,
{ // Required methods fn chars_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharsWithTrie<'slice, 'trie, T, V> ; fn char_indices_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V> ; }
Convenience trait that adds chars_with_trie() and char_indices_with_trie() methods similar to the ones icu_collections::codepointtrie::CharsWithTrieEx adds to string slices to u16 slices.

Required Methods

fn chars_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharsWithTrie<'slice, 'trie, T, V>

Convenience method for creating an UTF-16 iterator with trie values for the slice.

fn char_indices_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V>

Convenience method for creating a code unit index and UTF-16 iterator with trie values for the slice.

Implementations on Foreign Types

Source

impl<'slice, 'trie, T, V> Utf16CharsWithTrieEx<'slice, 'trie, T, V> for [u16]
where V: TrieValue, T: AbstractCodePointTrie<'trie, V>,

Source

fn chars_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharsWithTrie<'slice, 'trie, T, V>

Convenience method for creating an UTF-16 iterator with trie values for the slice.

Source

fn char_indices_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V>

Convenience method for creating a code unit index and UTF-16 iterator with trie values for the slice.

Implementors