pub trait Utf16CharsWithTrieEx<'slice, 'trie, T, V>where
V: TrieValue,
T: AbstractCodePointTrie<'trie, V>,{
// Required methods
fn chars_with_trie(
&'slice self,
trie: &'trie T,
) -> Utf16CharsWithTrie<'slice, 'trie, T, V> ⓘ;
fn char_indices_with_trie(
&'slice self,
trie: &'trie T,
) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V> ⓘ;
}Expand description
Convenience trait that adds chars_with_trie() and char_indices_with_trie() methods
similar to the ones icu_collections::codepointtrie::CharsWithTrieEx adds to string
slices to u16 slices.
Required Methods
Sourcefn chars_with_trie(
&'slice self,
trie: &'trie T,
) -> Utf16CharsWithTrie<'slice, 'trie, T, V> ⓘ
fn chars_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharsWithTrie<'slice, 'trie, T, V> ⓘ
Convenience method for creating an UTF-16 iterator with trie values for the slice.
Sourcefn char_indices_with_trie(
&'slice self,
trie: &'trie T,
) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V> ⓘ
fn char_indices_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V> ⓘ
Convenience method for creating a code unit index and UTF-16 iterator with trie values for the slice.
Implementations on Foreign Types
Sourceimpl<'slice, 'trie, T, V> Utf16CharsWithTrieEx<'slice, 'trie, T, V> for [u16]where
V: TrieValue,
T: AbstractCodePointTrie<'trie, V>,
impl<'slice, 'trie, T, V> Utf16CharsWithTrieEx<'slice, 'trie, T, V> for [u16]where
V: TrieValue,
T: AbstractCodePointTrie<'trie, V>,
Sourcefn chars_with_trie(
&'slice self,
trie: &'trie T,
) -> Utf16CharsWithTrie<'slice, 'trie, T, V> ⓘ
fn chars_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharsWithTrie<'slice, 'trie, T, V> ⓘ
Convenience method for creating an UTF-16 iterator with trie values for the slice.
Sourcefn char_indices_with_trie(
&'slice self,
trie: &'trie T,
) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V> ⓘ
fn char_indices_with_trie( &'slice self, trie: &'trie T, ) -> Utf16CharIndicesWithTrie<'slice, 'trie, T, V> ⓘ
Convenience method for creating a code unit index and UTF-16 iterator with trie values for the slice.